/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.nachlauf;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ste.stealgsba.algorithmen.nachlauf.ParameterNachlauf.Reaktion;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeNachlaufAnalyse!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.1 $ / $Date: 2015/03/24 14:40:43 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class NachlaufAnalyse
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeNachlaufAnalyse";
	/**
	 * Referenz auf eine Ursacheneinheit.
	 */
	private SystemObject m_ursacheneinheit;
	/**
	 * Reaktion Ein-/Auschaltung.
	 */
	private Reaktion m_reaktion;
	/**
	 * Einschaltdauer in Millisekunden.
	 */
	private long m_einschaltdauer;
	/**
	 * Status der Input Ursacheneinheit.
	 */
	private boolean m_statusInput;
	/**
	 * Kennung Nachlauf aktiv.
	 */
	private boolean m_nachlaufAktiv;
	/**
	 * Zeitpunkt fr das Nachlaufende in Millisekunden.
	 */
	private long m_nachlaufEnde;
	/**
	 * aktueller Status der Ursacheneinheit.
	 */
	private boolean m_status;
	
	/**
	 * Default-Konstruktor der Klasse.
	 */
	public NachlaufAnalyse()
	{
		
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeVerknpfungAnalyse</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{
			dataNeu.getReferenceValue("Ursacheneinheit").setSystemObject(getUrsacheneinheit());
			dataNeu.getScaledValue("Reaktion").setText(Reaktion.getText(getReaktion()));
			dataNeu.getTimeValue("Einschaltdauer").setMillis(getEinschaltdauer());
			dataNeu.getScaledValue("StatusInput").setText(isStatusInput() ? "Ja" : "Nein");								
			dataNeu.getScaledValue("NachlaufAktiv").setText(isNachlaufAktiv() ? "Ja" : "Nein");								
			
			dataNeu.getTimeValue("NachlaufEnde").setMillis(connection.getTime());
			if (getNachlaufEnde() > 0)
				dataNeu.getTimeValue("NachlaufEnde").setMillis(getNachlaufEnde());
			dataNeu.getScaledValue("Status").setText(isStatus() ? "Ja" : "Nein");
			
			return dataNeu;
		}
		
		return null;
	}
	
	
	/**
	 * Gibt den Wert der Variable m_ursacheneinheit zurck.
	 *
	 * @return Wert der Variable m_ursacheneinheit.
	 */
	public SystemObject getUrsacheneinheit()
	{
		return m_ursacheneinheit;
	}

	/**
	 * Setzt den Wert der Variable m_ursacheneinheit.
	 *
	 * @param ursacheneinheit zu setzender Wert der Variable m_ursacheneinheit.
	 */
	public void setUrsacheneinheit(SystemObject ursacheneinheit)
	{
		m_ursacheneinheit = ursacheneinheit;
	}

	/**
	 * Gibt den Wert der Variable m_reaktion zurck.
	 *
	 * @return Wert der Variable m_reaktion.
	 */
	public Reaktion getReaktion()
	{
		return m_reaktion;
	}

	/**
	 * Setzt den Wert der Variable m_reaktion.
	 *
	 * @param reaktion zu setzender Wert der Variable m_reaktion.
	 */
	public void setReaktion(Reaktion reaktion)
	{
		m_reaktion = reaktion;
	}

	/**
	 * Gibt den Wert der Variable m_einschaltdauer zurck.
	 *
	 * @return Wert der Variable m_einschaltdauer.
	 */
	public long getEinschaltdauer()
	{
		return m_einschaltdauer;
	}

	/**
	 * Setzt den Wert der Variable m_einschaltdauer.
	 *
	 * @param einschaltdauer zu setzender Wert der Variable m_einschaltdauer.
	 */
	public void setEinschaltdauer(long einschaltdauer)
	{
		m_einschaltdauer = einschaltdauer;
	}

	/**
	 * Gibt den Wert der Variable m_statusInput zurck.
	 *
	 * @return Wert der Variable m_statusInput.
	 */
	public boolean isStatusInput()
	{
		return m_statusInput;
	}

	/**
	 * Setzt den Wert der Variable m_statusInput.
	 *
	 * @param statusInput zu setzender Wert der Variable m_statusInput.
	 */
	public void setStatusInput(boolean statusInput)
	{
		m_statusInput = statusInput;
	}

	/**
	 * Gibt den Wert der Variable m_nachlaufAktiv zurck.
	 *
	 * @return Wert der Variable m_nachlaufAktiv.
	 */
	public boolean isNachlaufAktiv()
	{
		return m_nachlaufAktiv;
	}

	/**
	 * Setzt den Wert der Variable m_nachlaufAktiv.
	 *
	 * @param nachlaufAktiv zu setzender Wert der Variable m_nachlaufAktiv.
	 */
	public void setNachlaufAktiv(boolean nachlaufAktiv)
	{
		m_nachlaufAktiv = nachlaufAktiv;
	}

	/**
	 * Gibt den Wert der Variable m_nachlaufEnde zurck.
	 *
	 * @return Wert der Variable m_nachlaufEnde.
	 */
	public long getNachlaufEnde()
	{
		return m_nachlaufEnde;
	}

	/**
	 * Setzt den Wert der Variable m_nachlaufEnde.
	 *
	 * @param nachlaufEnde zu setzender Wert der Variable m_nachlaufEnde.
	 */
	public void setNachlaufEnde(long nachlaufEnde)
	{
		m_nachlaufEnde = nachlaufEnde;
	}

	/**
	 * Gibt den Wert der Variable m_status zurck.
	 *
	 * @return Wert der Variable m_status.
	 */
	public boolean isStatus()
	{
		return m_status;
	}

	/**
	 * Setzt den Wert der Variable m_status.
	 *
	 * @param status zu setzender Wert der Variable m_status.
	 */
	public void setStatus(boolean status)
	{
		m_status = status;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "NachlaufAnalyse [m_ursacheneinheit=" + m_ursacheneinheit + ", m_reaktion=" + m_reaktion + ", m_einschaltdauer=" + m_einschaltdauer + ", m_statusInput=" + m_statusInput
				+ ", m_nachlaufAktiv=" + m_nachlaufAktiv + ", m_nachlaufEnde=" + m_nachlaufEnde + ", m_status=" + m_status + "]";
	}
}
